{{/* vim: set filetype=mustache: */}}
{{/*
Expand the name of the chart.
*/}}
{{- define "collector.name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name.
*/}}
{{- define "collector.fullname" -}}
{{- if .Values.fullnameOverride -}}
{{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- $name := default .Chart.Name .Values.nameOverride -}}
{{- if contains $name .Release.Name -}}
{{- .Release.Name | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- printf "%s-%s" .Release.Name $name | trunc 63 | trimSuffix "-" -}}
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "collector.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Create the name of the service account to use for creating or deleting the collector
*/}}
{{- define "collector.serviceAccount" -}}
{{- if .Values.serviceAccount.create -}}
    {{ default (include "collector.fullname" .) .Values.serviceAccount.name }}
{{- else -}}
    {{ default "default" .Values.serviceAccount.name }}
{{- end -}}
{{- end -}}

{{/*
Create the name for the credentials secret.
*/}}
{{- define "collector.secretName" -}}
{{- if .Values.credentials.existingSecret -}}
  {{- .Values.credentials.existingSecret -}}
{{- else -}}
  {{ default (include "collector.fullname" .) .Values.credentials.name }}
{{- end -}}
{{- end -}}

{{/*
Compute if the otel-collector is enabled.
*/}}
{{- define "otel.otelEnabled" -}}
{{- $_ := set . "otelEnabled" (or
  (eq (.Values.otel.enabled | toString) "true")
  (and (eq (.Values.otel.enabled | toString) "-") (eq (.Values.global.enabled | toString) "true"))) -}}
{{- end -}}

{{/*
Compute if the pixie monitoring is enabled.
*/}}
{{- define "pixie.pixieEnabled" -}}
{{- $_ := set . "pixieEnabled" (or
  (eq (.Values.pixie.enabled | toString) "true")
  (and (eq (.Values.pixie.enabled | toString) "-") (eq (.Values.global.enabled | toString) "true"))) -}}
{{- end -}}

{{/*
Compute the list of extra pipeline trace exporters
*/}}
{{- define "otel.extraPipelineTraceExporters" -}}
{{ $_ := set . "extraPipelineTraceExporters" (concat ( list "logging" ) .Values.otel.extraPipelineTraceExporters) }}
{{- end -}}

{{/*
imagePullSecrets generates pull secrets from either string or map values.
A map value must be indexable by the key 'name'.
*/}}
{{- define "imagePullSecrets" -}}
{{- with .Values.global.imagePullSecrets -}}
imagePullSecrets:
{{- range . -}}
{{- if typeIs "string" . }}
  - name: {{ . }}
{{- else if index . "name" }}
  - name: {{ .name }}
{{- end }}
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
Sets the otel deployment update strategy
*/}}
{{- define "otel.strategy" -}}
  {{- if .Values.otel.strategy }}
  strategy:
  {{- $tp := typeOf .Values.otel.strategy }}
  {{- if eq $tp "string" }}
    {{ tpl .Values.otel.strategy . | nindent 4 | trim }}
  {{- else }}
    {{- toYaml .Values.otel.strategy | nindent 4 }}
  {{- end }}
  {{- end }}
{{- end -}}

{{/*
Sets extra otel pod annotations
*/}}
{{- define "otel.annotations" -}}
  {{- if .Values.otel.annotations }}
      annotations:
        {{- $tp := typeOf .Values.otel.annotations }}
        {{- if eq $tp "string" }}
          {{- tpl .Values.otel.annotations . | nindent 4 }}
        {{- else }}
          {{- toYaml .Values.otel.annotations | nindent 4 }}
        {{- end }}
  {{- end }}
{{- end -}}

{{/*
Sets extra otel PVC annotations
*/}}
{{- define "otel.persistentVolume.annotations" -}}
  {{- if .Values.otel.persistentVolume.annotations }}
      annotations:
        {{- $tp := typeOf .Values.otel.persistentVolume.annotations }}
        {{- if eq $tp "string" }}
          {{- tpl .Values.otel.persistentVolume.annotations . | nindent 8 }}
        {{- else }}
          {{- toYaml .Values.otel.persistentVolume.annotations | nindent 8 }}
        {{- end }}
  {{- end }}
{{- end -}}

{{/*
Sets the otel affinity for pod placement
*/}}
{{- define "otel.affinity" -}}
  {{- if .Values.otel.affinity }}
      affinity:
        {{ $tp := typeOf .Values.otel.affinity }}
        {{- if eq $tp "string" }}
          {{- tpl .Values.otel.affinity . | nindent 8 | trim }}
        {{- else }}
          {{- toYaml .Values.otel.affinity | nindent 8 }}
        {{- end }}
  {{ end }}
{{- end -}}

{{/*
Sets the otel topologySpreadConstraints for pod placement
*/}}
{{- define "otel.topologySpreadConstraints" -}}
  {{- if .Values.otel.topologySpreadConstraints }}
      topologySpreadConstraints:
        {{ $tp := typeOf .Values.otel.topologySpreadConstraints }}
        {{- if eq $tp "string" }}
          {{- tpl .Values.otel.topologySpreadConstraints . | nindent 8 | trim }}
        {{- else }}
          {{- toYaml .Values.otel.topologySpreadConstraints | nindent 8 }}
        {{- end }}
  {{ end }}
{{- end -}}

{{/*
Sets the otel toleration for pod placement
*/}}
{{- define "otel.tolerations" -}}
  {{- if .Values.otel.tolerations }}
      tolerations:
      {{- $tp := typeOf .Values.otel.tolerations }}
      {{- if eq $tp "string" }}
        {{ tpl .Values.otel.tolerations . | nindent 8 | trim }}
      {{- else }}
        {{- toYaml .Values.otel.tolerations | nindent 8 }}
      {{- end }}
  {{- end }}
{{- end -}}

{{/*
Sets the otel node selector for pod placement
*/}}
{{- define "otel.nodeselector" -}}
  {{- if .Values.otel.nodeSelector }}
      nodeSelector:
      {{- $tp := typeOf .Values.otel.nodeSelector }}
      {{- if eq $tp "string" }}
        {{ tpl .Values.otel.nodeSelector . | nindent 8 | trim }}
      {{- else }}
        {{- toYaml .Values.otel.nodeSelector | nindent 8 }}
      {{- end }}
  {{- end }}
{{- end -}}

{{/*
securityContext for the otel pod level.
*/}}
{{- define "otel.securityContext.pod" -}}
  {{- if .Values.otel.securityContext.pod }}
      securityContext:
        {{- $tp := typeOf .Values.otel.securityContext.pod }}
        {{- if eq $tp "string" }}
          {{- tpl .Values.otel.securityContext.pod . | nindent 8 }}
        {{- else }}
          {{- toYaml .Values.otel.securityContext.pod | nindent 8 }}
        {{- end }}
  {{- else if not .Values.global.openshift }}
      securityContext:
        runAsNonRoot: true
        runAsGroup: {{ .Values.otel.gid | default 1000 }}
        runAsUser: {{ .Values.otel.uid | default 100 }}
        fsGroup: {{ .Values.otel.gid | default 1000 }}
  {{- end }}
{{- end -}}

{{/*
Sets the container resources if the user has set any.
*/}}
{{- define "otel.resources" -}}
  {{- if .Values.otel.resources -}}
          resources:
{{ toYaml .Values.otel.resources | indent 12}}
  {{ end }}
{{- end -}}

{{/*
securityContext for the otel container level.
*/}}
{{- define "otel.securityContext.container" -}}
  {{- if .Values.otel.securityContext.container}}
          securityContext:
            {{- $tp := typeOf .Values.otel.securityContext.container }}
            {{- if eq $tp "string" }}
              {{- tpl .Values.otel.securityContext.container . | nindent 12 }}
            {{- else }}
              {{- toYaml .Values.otel.securityContext.container | nindent 12 }}
            {{- end }}
  {{- else if not .Values.global.openshift }}
          securityContext:
            allowPrivilegeEscalation: false
            capabilities:
              drop:
                - ALL
  {{- end }}
{{- end -}}

{{/*
Inject extra environment vars in the format key:value, if populated
*/}}
{{- define "otel.extraEnvironmentVars" -}}
{{- if .extraEnvironmentVars -}}
{{- range $key, $value := .extraEnvironmentVars }}
- name: {{ printf "%s" $key | replace "." "_" | upper | quote }}
  value: {{ $value | quote }}
{{- end }}
{{- end -}}
{{- end -}}

{{/*
Inject extra environment populated by secrets, if populated
*/}}
{{- define "otel.extraSecretEnvironmentVars" -}}
{{- if .extraSecretEnvironmentVars -}}
{{- range .extraSecretEnvironmentVars }}
- name: {{ .envName }}
  valueFrom:
   secretKeyRef:
     name: {{ .secretName }}
     key: {{ .secretKey }}
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
Set's which additional volumes should be mounted to the container.
*/}}
{{- define "otel.mounts" -}}
  {{- range .Values.otel.extraVolumes }}
            - name: userconfig-{{ .name }}
              readOnly: true
              mountPath: {{ .path | default "/otel/userconfig" }}/{{ .name }}
  {{- end }}
  {{- if .Values.otel.volumeMounts }}
    {{- toYaml .Values.otel.volumeMounts | nindent 12}}
  {{- end }}
{{- end -}}

{{/*
Iterates over any extra volumes the user may have specified (such as a secret
with TLS).
*/}}
{{- define "otel.volumes" -}}
  {{- range .Values.otel.extraVolumes }}
        - name: userconfig-{{ .name }}
          {{ .type }}:
          {{- if (eq .type "configMap") }}
            name: {{ .name }}
          {{- else if (eq .type "secret") }}
            secretName: {{ .name }}
          {{- end }}
            defaultMode: {{ .defaultMode | default 420 }}
  {{- end }}
  {{- if .Values.otel.volumes }}
    {{- toYaml .Values.otel.volumes | nindent 8}}
  {{- end }}
{{- end -}}
